@@ -2,18 +2,20 @@ import logging
 import typing
 from typing import Any, Optional, Text, Tuple, Union, Dict
 
+import rasa.shared.utils.common
 import rasa.utils.common as common_utils
-from rasa.nlu import config
+from rasa.nlu import config, utils
 from rasa.nlu.components import ComponentBuilder
 from rasa.nlu.config import RasaNLUModelConfig
 from rasa.nlu.model import Interpreter, Trainer
-from rasa.nlu.training_data import load_data
-from rasa.nlu.training_data.loading import load_data_from_endpoint
+from rasa.shared.nlu.training_data.loading import load_data
+from rasa.utils import io as io_utils
 from rasa.utils.endpoints import EndpointConfig
 
 
 if typing.TYPE_CHECKING:
-    from rasa.importers.importer import TrainingDataImporter
+    from rasa.shared.importers.importer import TrainingDataImporter
+    from rasa.shared.nlu.training_data.training_data import TrainingData
 
 logger = logging.getLogger(__name__)
 
@@ -21,10 +23,10 @@ logger = logging.getLogger(__name__)
 class TrainingException(Exception):
     """Exception wrapping lower level exceptions that may happen while training
 
-      Attributes:
-          failed_target_project -- name of the failed project
-          message -- explanation of why the request is invalid
-      """
+    Attributes:
+        failed_target_project -- name of the failed project
+        message -- explanation of why the request is invalid
+    """
 
     def __init__(
         self,
@@ -36,11 +38,31 @@ class TrainingException(Exception):
             self.message = exception.args[0]
         else:
             self.message = ""
+        super(TrainingException, self).__init__()
 
     def __str__(self) -> Text:
         return self.message
 
 
+async def load_data_from_endpoint(
+    data_endpoint: EndpointConfig, language: Optional[Text] = "en"
+) -> "TrainingData":
+    """Load training data from a URL."""
+    import requests
+
+    if not utils.is_url(data_endpoint.url):
+        raise requests.exceptions.InvalidURL(data_endpoint.url)
+    try:
+        response = await data_endpoint.request("get")
+        response.raise_for_status()
+        temp_data_file = io_utils.create_temporary_file(response.content, mode="w+b")
+        training_data = load_data(temp_data_file, language)
+
+        return training_data
+    except Exception as e:
+        logger.warning(f"Could not retrieve training data from URL:\n{e}")
+
+
 def create_persistor(persistor: Optional[Text]):
     """Create a remote persistor to store the model if configured."""
 
@@ -64,7 +86,7 @@ async def train(
     **kwargs: Any,
 ) -> Tuple[Trainer, Interpreter, Optional[Text]]:
     """Loads the trainer and the data and runs the training of the model."""
-    from rasa.importers.importer import TrainingDataImporter
+    from rasa.shared.importers.importer import TrainingDataImporter
 
     if not isinstance(nlu_config, RasaNLUModelConfig):
         nlu_config = config.load(nlu_config)
@@ -85,7 +107,9 @@ async def train(
 
     training_data.print_stats()
     if training_data.entity_roles_groups_used():
-        common_utils.mark_as_experimental_feature("Entity Roles and Groups feature")
+        rasa.shared.utils.common.mark_as_experimental_feature(
+            "Entity Roles and Groups feature"
+        )
 
     interpreter = trainer.train(training_data, **kwargs)
 
@@ -97,11 +121,3 @@ async def train(
         persisted_path = None
 
     return trainer, interpreter, persisted_path
-
-
-if __name__ == "__main__":
-    raise RuntimeError(
-        "Calling `rasa.nlu.train` directly is no longer supported. Please use "
-        "`rasa train` to train a combined Core and NLU model or `rasa train nlu` "
-        "to train an NLU model."
-    )
